@@ -90,9 +90,9 @@ extern OSI_MANAGEMENT_CONFIG *config;
 #define NOTIFY_SESSION_REKEY_FORMAT "The host, \"%s\" seems to have lost its \
 resident session key.\r\nThis key is lost when the agent is restarted \
 or the host is rebooted.\
-\r\n\r\nThis host is configured to send a notification upon detection of \
-this event.\r\nTo change this, login to the management console and edit \
-the configuration for this host.\r\n\r\n"
+\r\n\r\nThis host is configured to generate an alert upon detection of \
+this event.\r\nTo change this, adjust the notification settings for \
+this host.\r\n\r\n"
 
 #define NOTIFY_UPDATE_URL_FORMAT "If these changes are approved, visit the \
 URL below to set the latest scan database to become the trusted database. \
@@ -400,7 +400,7 @@ static int connect_to_mail_server( const char *email, OSI_ERROR *error )
     return sock;
 }
 
-void md_notify_admin_session_rekey( const char *host, const char *email )
+void md_notify_session_rekey( const char *host, const char *email )
 {
     int sock = 0;
 
@@ -415,17 +415,14 @@ void md_notify_admin_session_rekey( const char *host, const char *email )
         return;
     }
 
-    if( ( sock = connect_to_mail_server( email, NULL ) ) < 0 )
+    if ( email && strlen( email ) == 0 )
     {
         return;
     }
 
-    /* make sure we have a valid email address, after the connect, */
-    /* at least one should be valid.                               */
-
-    if ( email && strlen( email ) == 0 )
+    if( ( sock = connect_to_mail_server( email, NULL ) ) < 0 )
     {
-        from_email = config->admin_email;
+        return;
     }
 
     if( config->http_host[0] && strcmp( config->http_host, "" ) != 0 )
@@ -448,7 +445,7 @@ void md_notify_admin_session_rekey( const char *host, const char *email )
                   "To: %s\r\n"
                   "From: \"Osiris Host Integrity System\" <osirismd@%s>\r\n"
                   "Date: %s\r\n"
-                  "Subject: [host: %s] session rekey.\r\n\r\n",
+                  "Subject: [osiris rekey][host: %s] session rekey.\r\n\r\n",
                   from_email, this_host,
                   osi_time_to_string(osi_get_time()), host );
 
@@ -464,7 +461,7 @@ void md_notify_admin_session_rekey( const char *host, const char *email )
     return;
 } 
 
-void md_notify_admin_scan_failed( const char *host,
+void md_notify_scan_failed( const char *host,
                                   const char *email,
                                   unsigned long scheduled_time,
                                   const char *message )
@@ -483,6 +480,11 @@ void md_notify_admin_scan_failed( const char *host,
         return;
     }
 
+    if ( email && strlen( email ) == 0 )
+    {
+        return;
+    }
+
     /* if we were given a scheduled time, we get it as a string. */
 
     if( scheduled_time > 0 )
@@ -500,11 +502,6 @@ void md_notify_admin_scan_failed( const char *host,
         return;
     }
 
-    if ( email && strlen( email ) == 0 )
-    {
-        from_email = config->admin_email;
-    }
-
     if( config->http_host[0] && strcmp( config->http_host, "" ) != 0 )
     {
         osi_snprintf( this_host, sizeof(this_host), "%s", config->http_host );
@@ -525,7 +522,7 @@ void md_notify_admin_scan_failed( const char *host,
                   "To: %s\r\n"
                   "From: \"Osiris Host Integrity System\" <osirismd@%s>\r\n"
                   "Date: %s\r\n"
-             "Subject: [host: %s] failed to start the scheduled scan.\r\n\r\n",
+"Subject: [osiris scheduler][host: %s] failed to start the scheduled scan.\r\n\r\n",
                   from_email, this_host,
                   osi_time_to_string(osi_get_time()), host );
 
@@ -543,7 +540,7 @@ void md_notify_admin_scan_failed( const char *host,
     return;
 }
 
-void md_notify_admin( const char *email, OSI_DB_CTX *context,osi_bool show_url )
+void md_notify( const char *email, OSI_DB_CTX *context,osi_bool show_url )
 {
     int sock = 0;
     int diff_count = context->diff_count;
@@ -564,17 +561,17 @@ void md_notify_admin( const char *email, OSI_DB_CTX *context,osi_bool show_url )
         return;
     }
 
+    if ( email && strlen( email ) == 0 )
+    {
+        return;
+    }
+
     if ( ( sock = connect_to_mail_server( email, NULL ) ) < 0  )
     {
         return;
     }
 
-    if ( email && strlen( email ) == 0 )
-    {
-        from_email = config->admin_email;
-    }
-
-   log_info( LOG_ID_NOTIFY_ERROR, context->host,
+   log_info( LOG_ID_NOTIFY_INFO, context->host,
             "notifying %s using %s:%d, sending contents of log file: %s, "
             "containing %d entries.",
             from_email, smtp_host, smtp_port,logfile, diff_count);
@@ -601,7 +598,7 @@ void md_notify_admin( const char *email, OSI_DB_CTX *context,osi_bool show_url )
                   "To: %s\r\n"
                   "From: \"Osiris Host Integrity System\" <osirismd@%s>\r\n"
                   "Date: %s\r\n"
-                  "Subject: [host: %s][%d changes]\r\n\r\n",
+                  "Subject: [osiris log][host: %s][%d changes]\r\n\r\n",
                   from_email, host, osi_time_to_string( osi_get_time() ),
                   context->host, diff_count );
 
@@ -659,6 +656,11 @@ osi_bool md_notify_send_test( const char *email, OSI_ERROR *error )
         return FALSE;
     }
 
+    if ( email && strlen( email ) == 0 )
+    {
+        return FALSE;
+    }
+
     memset( error, 0, sizeof( OSI_ERROR ) );
 
     if( ( sock = connect_to_mail_server( email, error ) ) < 0 )
@@ -666,11 +668,6 @@ osi_bool md_notify_send_test( const char *email, OSI_ERROR *error )
         return FALSE;
     }
 
-    if ( email && strlen( email ) == 0 )
-    {
-        from_email = config->admin_email;
-    }
-
     if( config->http_host[0] && strcmp( config->http_host, "" ) != 0 )
     {
         osi_snprintf( this_host, sizeof(this_host), "%s", config->http_host );
@@ -691,7 +688,7 @@ osi_bool md_notify_send_test( const char *email, OSI_ERROR *error )
                   "To: %s\r\n"
                   "From: \"Osiris Host Integrity System\" <osirismd@%s>\r\n"
                   "Date: %s\r\n"
-                  "Subject: [osiris test message]\r\n\r\n",
+                  "Subject: [osiris test][notification system test]\r\n\r\n",
                   from_email, this_host, osi_time_to_string( osi_get_time() ) );
 
      send_smtp_command( sock, buf, NULL );
